@@ -17,19 +17,22 @@ __all__ = ['_calc_A',
 		   '_calc_rmse',
 		   '_calc_Rpr',
 		   '_fHea14',
-		   '_fHH20',
+		   '_fHH21',
 		   '_fPH12',
 		   '_fSE15',
 		   '_Gaussian',
 		   '_ghHea14',
-		   '_ghHH20',
+		   '_ghHH21',
 		   '_ghPH12',
 		   '_ghSE15',
 		   '_Jacobian',
+		   'Deq_from_T',
+		   'T_from_Deq'
 		  ]
 
 #import packages
 import numpy as np
+import types
 
 #import linear algebra functions
 from numpy import eye
@@ -49,10 +52,10 @@ from .dictionaries import(
 	d47_isoparams,
 	)
 
-#define function for calculating HH20 inverse A matrix
+#define function for calculating HH21 inverse A matrix
 def _calc_A(t, nu):
 	'''
-	Function for calculating A matrix for HH20 data inversion.
+	Function for calculating A matrix for HH21 data inversion.
 
 	Parameters
 	----------
@@ -73,7 +76,7 @@ def _calc_A(t, nu):
 	----------
 
 	[1] Forney and Rothman (2012) *J. Royal Soc. Inter.*, **9**, 2255--2267.\n
-	[2] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[2] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **566**, 116962.
 	'''
 
 	#extract constants
@@ -89,7 +92,7 @@ def _calc_A(t, nu):
 	
 	return A
 
-#define function for calculating HH20 inverse R matrix
+#define function for calculating HH21 inverse R matrix
 def _calc_R(n):
 	'''
 	Calculates smoothing matrix, R.
@@ -363,8 +366,8 @@ def _fHea14(t, lnkc, lnkd, lnk2, logG = True):
 
 	return Ghat
 
-#function to fit data to lognormal decay k distribution for HH20  model
-def _fHH20(t, mu_nu, sig_nu, nu_max, nu_min, nnu):
+#function to fit data to lognormal decay k distribution for HH21  model
+def _fHH21(t, mu_nu, sig_nu, nu_max, nu_min, nnu):
 	'''
 	Function to calculate G as a function of time assuming a lognormal 
 	distribution of decay rates described by mu and sigma.
@@ -401,7 +404,7 @@ def _fHH20(t, mu_nu, sig_nu, nu_max, nu_min, nnu):
 	References
 	----------
 
-	[1] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[1] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **566**, 116962.
 	'''
 
 	#setup arrays
@@ -470,9 +473,9 @@ def _fSE15(
 	mp, 
 	d0, 
 	T, 
-	calibration = 'Bea17', 
-	iso_params = 'Gonfiantini', 
-	ref_frame = 'CDES90',
+	calibration = 'Aea21', 
+	iso_params = 'Brand', 
+	ref_frame = 'I-CDES',
 	z = 6
 	):
 	'''
@@ -507,13 +510,20 @@ def _fSE15(
 	T : float
 		The experimental temperature, in Kelvin.
 
-	calibration : string
-		The D-T calibration curve to use, from the literature. Options are: \n
-			``'PH12'``: for Passey and Henkes (2012) Eq. 4 \n
-			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 \n
-			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 \n
-		Note that literature equations will be adjusted to be consistent with 
-		any reference frame. Defaults to ``'Bea17'``.
+	calibration : string or lambda function
+		The D-T calibration curve to use, either from the literature or as
+		a user-inputted lambda function. If from the literature for D47
+		clumps, options are: \n
+			``'PH12'``: for Passey and Henkes (2012) Eq. 4 (CDES 25C)\n
+			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 (Ghosh 25C)\n
+			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 (CDES 90C) \n
+			``'Aea21'``: for Anderson et al. (2021) Eq. 1 (I-CDES) \n
+		If as a lambda function, must have T in Kelvin. It is recommended to
+		run each calibration only using its native reference frame (denoted in
+		parentheses); although these will be automatically adjusted to different
+		reference frames, **there is no guarantee that this conversion is
+		accurate for all analytical setups**. In contrast, lambda functions must
+		be reference-frame specific. Defaults to ``'Aea21'``.
 
 	iso_params : string
 		The isotope parameters used to calculate clumped data. For example, if
@@ -528,18 +538,19 @@ def _fSE15(
 			``'Craig+Li'``: for Craig (1957) + Li et al. (1988)\n
 			``'Gonfiantini'``: for Gonfiantini et al. (1995)\n
 			``'Passey'``: for Passey et al. (2014) lam17\n
-		Defaults to ``'Gonfiantini'``.
+		Defaults to ``'Brand'``.
 
 	ref_frame : string
 		The reference frame used to calculate clumped isotope data. Options
 		are:\n
 			``'CDES25'``: Carbion Dioxide Equilibrium Scale acidified at 25 C.\n
 			``'CDES90'``: Carbon Dioxide Equilibrium Scale acidified at 90 C.\n
-			``'Ghosh25'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 25 C.\n
-			``'Ghosh90'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 90 C.\n
-		Defaults to ``'CDES90'``.
+			``'Ghosh'``: Heated Gas Line Reference Frame of Ghosh et al. (2006)
+			acidified at 25 C.\n
+			``'I-CDES'``: Carbon Dioxide Equilibrium Scale acidified at 90 C,
+			referenced to carbonate standards as described in Bernasconi et al.
+			(2021).
+		Defaults to ``'I-CDES'``.
 
 	z : int
 		The mineral lattice coordination number to use for calculating the
@@ -776,10 +787,10 @@ def _ghHea14(t, Ec, lnkcref, Ed, lnkdref, E2, lnk2ref, D0, Deq, T, Tref):
 
 	return D
 
-#function for calcualting geologic history with HH20 model
-def _ghHH20(t, Emu, lnkmuref, Esig, lnksigref, D0, Deq, T, Tref, nnu = 400):
+#function for calcualting geologic history with HH21 model
+def _ghHH21(t, Emu, lnkmuref, Esig, lnksigref, D0, Deq, T, Tref, nnu = 400):
 	'''
-	Calculates the D47 value for a given geologic t-T history using the HH20
+	Calculates the D47 value for a given geologic t-T history using the HH21
 	model.
 
 	Parameters
@@ -790,16 +801,16 @@ def _ghHH20(t, Emu, lnkmuref, Esig, lnksigref, D0, Deq, T, Tref, nnu = 400):
 		were used to calculate lnkref values. Length ``nt``.
 
 	Emu : float
-		The activation energy value "mu" for the HH20 model.
+		The activation energy value "mu" for the HH21 model.
 
 	lnkmuref : float
-		The reference lnk value "mu" for the HH20 model.
+		The reference lnk value "mu" for the HH21 model.
 
 	Esig : float
-		The activation energy value "sig" for the HH20 model.
+		The activation energy value "sig" for the HH21 model.
 
 	lnksigref : float
-		The reference lnk value "sig" for the HH20 model.
+		The reference lnk value "sig" for the HH21 model.
 
 
 	D0 : float
@@ -830,45 +841,89 @@ def _ghHH20(t, Emu, lnkmuref, Esig, lnksigref, D0, Deq, T, Tref, nnu = 400):
 	References
 	----------
 
-	[1] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[1] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **566**, 116962.
 	'''
 
+	#----------------------------------#
+	# NEW CODE USING UPDATED EQUATION! #
+	# JDH 25 August 2021               #
+	#----------------------------------#
+
 	#get constants
 	nt = len(t)
 	dt = np.gradient(t)
 	R = 8.314/1000 #in kJ/mol/K
 
-	#calculate overall k at each temperature point, termed kappa
-	#calculate nu_mu and nu_sig from Emu and Esig
-	nu_mu = lnkmuref + (Emu/R)*(1/Tref - 1/T)
-	nu_sig = lnksigref - (Esig/R)*(1/T)
+	#pre-allocate D matrix
+	Dmat = np.zeros([nnu,nt])
+	Dmat[:,0] = D0
 
-	#calculate pnu from nu_mu and nu_sig
-	# pnu is an [nt x nnu] matrix
+	#calculate E and p(E) arrays
+	#go from 5*Esig above Emu to 5*Esig below Emu
+	E_min = np.floor(Emu + 5*Esig)
+	E_max = np.ceil(Emu - 5*Esig)
 
-	#first, make nu array that spans from 5*sigma above max(nu_mu) to 5*sigma
-	# below min(nu_mu)
-	nu_min = np.floor(nu_mu.min() - 5*nu_sig.max())
-	nu_max = np.ceil(nu_mu.max() + 5*nu_sig.max())
+	#get E array
+	E = np.linspace(E_min, E_max, nnu)
+	dE = E[1] - E[0]
 
-	nu = np.linspace(nu_min, nu_max, nnu)
-	dnu = nu[1] - nu[0]
+	#get p(E) array
+	pE = _Gaussian(E, Emu, Esig)
 
-	#then, make into matrix
-	rhonu = _Gaussian(nu, nu_mu, nu_sig)
+	#get nu matrix from T and E arrays
+	numat = lnkmuref + np.outer((E/R),(1/Tref - 1/T))
 
-	#make array of kappa = integral(rho_nu * e^(-k*dt))
-	b = np.exp(-np.outer(np.exp(nu), dt))
-	kappa = np.sum(rhonu * b * dnu, axis = 0)
+	#calculate b, the exponential decay for each E value at each time step
+	b = np.exp(-np.exp(numat)*np.outer(np.ones(nnu),dt))
 
-	#pre-allocate D array
-	D = np.zeros(nt)
-	D[0] = D0
-
-	#loop through and solve for D at each time point
+	#loop through and solve for D(E,t)
 	for i in range(1,nt):
 
-		D[i] = (D[i-1] - Deq[i])*kappa[i] + Deq[i]
+	    Dmat[:,i] = (Dmat[:,i-1] - Deq[i])*b[:,i] + Deq[i]
+
+	#calcualte overall D value
+	D = np.sum(np.outer(pE,np.ones(nt))*Dmat*dE, axis = 0)
+
+	#-------------------------------------------------------------------------#
+	#OLD CODE: USED THE WRONG EQUATION FOR GEOLOGIC HISTORY RECONSTRUCTIONS!! #
+	#-------------------------------------------------------------------------#
+
+	# #get constants
+	# nt = len(t)
+	# dt = np.gradient(t)
+	# R = 8.314/1000 #in kJ/mol/K
+
+	# #calculate overall k at each temperature point, termed kappa
+	# #calculate nu_mu and nu_sig from Emu and Esig
+	# nu_mu = lnkmuref + (Emu/R)*(1/Tref - 1/T)
+	# nu_sig = lnksigref - (Esig/R)*(1/T)
+
+	# #calculate pnu from nu_mu and nu_sig
+	# # pnu is an [nt x nnu] matrix
+
+	# #first, make nu array that spans from 5*sigma above max(nu_mu) to 5*sigma
+	# # below min(nu_mu)
+	# nu_min = np.floor(nu_mu.min() - 5*nu_sig.max())
+	# nu_max = np.ceil(nu_mu.max() + 5*nu_sig.max())
+
+	# nu = np.linspace(nu_min, nu_max, nnu)
+	# dnu = nu[1] - nu[0]
+
+	# #then, make into matrix
+	# rhonu = _Gaussian(nu, nu_mu, nu_sig)
+
+	# #make array of kappa = integral(rho_nu * e^(-k*dt))
+	# b = np.exp(-np.outer(np.exp(nu), dt))
+	# kappa = np.sum(rhonu * b * dnu, axis = 0)
+
+	# #pre-allocate D array
+	# D = np.zeros(nt)
+	# D[0] = D0
+
+	# #loop through and solve for D at each time point
+	# for i in range(1,nt):
+
+	# 	D[i] = (D[i-1] - Deq[i])*kappa[i] + Deq[i]
 
 	return D
 
@@ -953,9 +1008,9 @@ def _ghSE15(
 	d18O,
 	T, 
 	Tref,
-	calibration = 'Bea17', 
-	iso_params = 'Gonfiantini', 
-	ref_frame = 'CDES90',
+	calibration = 'Aea21', 
+	iso_params = 'Brand', 
+	ref_frame = 'I-CDES',
 	z = 6
 	):
 	'''
@@ -1003,13 +1058,20 @@ def _ghSE15(
 	Tref : float
 		The reference temperature at which lnkref was calculated, in Kelvin.
 
-	calibration : string
-		The D-T calibration curve to use, from the literature. Options are: \n
-			``'PH12'``: for Passey and Henkes (2012) Eq. 4 \n
-			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 \n
-			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 \n
-		Note that literature equations will be adjusted to be consistent with 
-		any reference frame. Defaults to ``'Bea17'``.
+	calibration : string or lambda function
+		The D-T calibration curve to use, either from the literature or as
+		a user-inputted lambda function. If from the literature for D47
+		clumps, options are: \n
+			``'PH12'``: for Passey and Henkes (2012) Eq. 4 (CDES 25C)\n
+			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 (Ghosh 25C)\n
+			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 (CDES 90C) \n
+			``'Aea21'``: for Anderson et al. (2021) Eq. 1 (I-CDES) \n
+		If as a lambda function, must have T in Kelvin. It is recommended to
+		run each calibration only using its native reference frame (denoted in
+		parentheses); although these will be automatically adjusted to different
+		reference frames, **there is no guarantee that this conversion is
+		accurate for all analytical setups**. In contrast, lambda functions must
+		be reference-frame specific. Defaults to ``'Aea21'``.
 
 	iso_params : string
 		The isotope parameters used to calculate clumped data. For example, if
@@ -1024,18 +1086,19 @@ def _ghSE15(
 			``'Craig+Li'``: for Craig (1957) + Li et al. (1988)\n
 			``'Gonfiantini'``: for Gonfiantini et al. (1995)\n
 			``'Passey'``: for Passey et al. (2014) lam17\n
-		Defaults to ``'Gonfiantini'``.
+		Defaults to ``'Brand'``.
 
 	ref_frame : string
 		The reference frame used to calculate clumped isotope data. Options
 		are:\n
 			``'CDES25'``: Carbion Dioxide Equilibrium Scale acidified at 25 C.\n
 			``'CDES90'``: Carbon Dioxide Equilibrium Scale acidified at 90 C.\n
-			``'Ghosh25'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 25 C.\n
-			``'Ghosh90'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 90 C.\n
-		Defaults to ``'CDES90'``.
+			``'Ghosh'``: Heated Gas Line Reference Frame of Ghosh et al. (2006)
+			acidified at 25 C.\n
+			``'I-CDES'``: Carbon Dioxide Equilibrium Scale acidified at 90 C,
+			referenced to carbonate standards as described in Bernasconi et al.
+			(2021).
+		Defaults to ``'I-CDES'``.
 
 	z : int
 		The mineral lattice coordination number to use for calculating the
@@ -1196,7 +1259,7 @@ def _Jacobian(f, t, p, eps = 1e-6):
 	return J
 
 #function for calculating T from D
-def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
+def Deq_from_T(T, calibration = 'Aea21', clumps = 'CO47', ref_frame = 'I-CDES'):
 	'''
 	Calculates equilibrium clumped isotope values at a given temperature for
 	a given calibration and reference frame.
@@ -1208,13 +1271,20 @@ def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
 		The temperature values at which to calculate equilibrium D values,
 		in Kelvin. Can be a single temperature or an array of temperatures.
 
-	calibration : string
-		The D-T calibration curve to use, from the literature. Options are: \n
-			``'PH12'``: for Passey and Henkes (2012) Eq. 4 \n
-			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 \n
-			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 \n
-		Note that literature equations will be adjusted to be consistent with 
-		any reference frame. Defaults to ``'Bea17'``.
+	calibration : string or lambda function
+		The D-T calibration curve to use, either from the literature or as
+		a user-inputted lambda function. If from the literature for D47
+		clumps, options are: \n
+			``'PH12'``: for Passey and Henkes (2012) Eq. 4 (CDES 25C)\n
+			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 (Ghosh 25C)\n
+			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 (CDES 90C) \n
+			``'Aea21'``: for Anderson et al. (2021) Eq. 1 (I-CDES) \n
+		If as a lambda function, must have T in Kelvin. It is recommended to
+		run each calibration only using its native reference frame (denoted in
+		parentheses); although these will be automatically adjusted to different
+		reference frames, **there is no guarantee that this conversion is
+		accurate for all analytical setups**. In contrast, lambda functions must
+		be reference-frame specific. Defaults to ``'Aea21'``.
 
 	clumps : string
 		The clumped isotope system under consideration. Currently only
@@ -1227,11 +1297,12 @@ def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
 		are:\n
 			``'CDES25'``: Carbion Dioxide Equilibrium Scale acidified at 25 C.\n
 			``'CDES90'``: Carbon Dioxide Equilibrium Scale acidified at 90 C.\n
-			``'Ghosh25'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 25 C.\n
-			``'Ghosh90'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 90 C.\n
-		Defaults to ``'CDES90'``.
+			``'Ghosh'``: Heated Gas Line Reference Frame of Ghosh et al. (2006)
+			acidified at 25 C.\n
+			``'I-CDES'``: Carbon Dioxide Equilibrium Scale acidified at 90 C,
+			referenced to carbonate standards as described in Bernasconi et al.
+			(2021).
+		Defaults to ``'I-CDES'``.
 
 	Returns
 	-------
@@ -1245,7 +1316,7 @@ def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
 	------
 
 	TypeError
-		If inputted keyword arguments are not strings.
+		If inputted keyword arguments are not strings or lambda function.
 
 	TypeError
 		If inputted keyword arguments are not acceptable strings.
@@ -1282,12 +1353,39 @@ def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
 	[2] Dennis et al. (2011) *Geochim. Cosmochim. Ac.*, **75**, 7117--7131.\n
 	[3] Passey and Henkes (2012) *Earth Planet. Sci. Lett.*, **351**, 223--236.\n
 	[4] Stolper and Eiler (2015) *Am. J. Sci.*, **315**, 363--411.\n
-	[5] Bonifacie et al. (2017) *Geochim. Cosmochim. Ac.*, **200**, 255--279.
+	[5] Bonifacie et al. (2017) *Geochim. Cosmochim. Ac.*, **200**, 255--279. \n
+	[6] Anderson et al. (2021) *Geophys. Res. Lett.*, **48**, e2020GL092069. \n
 	'''
 
 	#make sure clumps is CO47 and extract from dictionary
 	if clumps == 'CO47':
-		Deq = caleqs[calibration][ref_frame](T)
+
+		#if calibration is a string, calculate Deq from the dictionaries
+		if isinstance(calibration, str):
+			
+			if calibration in ['PH12', 'SE15', 'Bea17', 'Aea21']:
+				#get Deq from dictionary
+				Deq = caleqs[calibration][ref_frame](T)
+
+			else:
+				#wrong string; raise error
+				raise ValueError(
+					"unexpected calibration %s. Must be 'PH12', 'SE15', 'Bea17',"
+					" Aea21', or lambda function."
+					% calibration
+					)
+
+		#if it's a lambda function, calculate Deq directly
+		elif isinstance(calibration, types.FunctionType):
+			Deq = calibration(T)
+
+		#if it's neither, raise typeerror
+		else:
+			ct = type(calibration).__name__
+			raise TypeError(
+				'unexpected calibration of type %s. Must be string or '
+				'LambdaType.' % ct
+				)
 	
 	elif isinstance(clumps, str):
 		raise ValueError(
@@ -1302,7 +1400,7 @@ def Deq_from_T(T, calibration = 'Bea17', clumps = 'CO47', ref_frame = 'CDES90'):
 	return Deq
 
 #function for calculating T from D
-def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Bea17', ref_frame = 'CDES90'):
+def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Aea21', ref_frame = 'I-CDES'):
 	'''
 	Calculates equilibrium temperature for a given clumped isotope value for
 	a given calibration and reference frame.
@@ -1314,13 +1412,20 @@ def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Bea17', ref_frame = 'CDES90'
 		The clumped isotope values at which to calculate equilibrium T values,
 		in Kelvin. Can be a single clumped isotope value or an array of values.
 
-	calibration : string
-		The D-T calibration curve to use, from the literature. Options are: \n
-			``'PH12'``: for Passey and Henkes (2012) Eq. 4 \n
-			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 \n
-			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 \n
-		Note that literature equations will be adjusted to be consistent with 
-		any reference frame. Defaults to ``'Bea17'``.
+	calibration : string or lambda function
+		The D-T calibration curve to use, either from the literature or as
+		a user-inputted lambda function. If from the literature for D47
+		clumps, options are: \n
+			``'PH12'``: for Passey and Henkes (2012) Eq. 4 (CDES 25C)\n
+			``'SE15'``: for Stolper and Eiler (2015) Fig. 3 (Ghosh 25C)\n
+			``'Bea17'``: for Bonifacie et al. (2017) Eq. 2 (CDES 90C) \n
+			``'Aea21'``: for Anderson et al. (2021) Eq. 1 (I-CDES) \n
+		If as a lambda function, must have T in Kelvin. It is recommended to
+		run each calibration only using its native reference frame (denoted in
+		parentheses); although these will be automatically adjusted to different
+		reference frames, **there is no guarantee that this conversion is
+		accurate for all analytical setups**. In contrast, lambda functions must
+		be reference-frame specific. Defaults to ``'Aea21'``.
 
 	clumps : string
 		The clumped isotope system under consideration. Currently only
@@ -1333,11 +1438,12 @@ def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Bea17', ref_frame = 'CDES90'
 		are:\n
 			``'CDES25'``: Carbion Dioxide Equilibrium Scale acidified at 25 C.\n
 			``'CDES90'``: Carbon Dioxide Equilibrium Scale acidified at 90 C.\n
-			``'Ghosh25'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 25 C.\n
-			``'Ghosh90'``: Heated Gas Line Reference Frame of Ghosh et al. 
-			(2006) acidified at 90 C.\n
-		Defaults to ``'CDES90'``.
+			``'Ghosh'``: Heated Gas Line Reference Frame of Ghosh et al. (2006)
+			acidified at 25 C.\n
+			``'I-CDES'``: Carbon Dioxide Equilibrium Scale acidified at 90 C,
+			referenced to carbonate standards as described in Bernasconi et al.
+			(2021).
+		Defaults to ``'I-CDES'``.
 
 	Returns
 	-------
@@ -1351,7 +1457,7 @@ def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Bea17', ref_frame = 'CDES90'
 	------
 
 	TypeError
-		If inputted keyword arguments are not strings.
+		If inputted keyword arguments are not strings (or lambda function).
 
 	TypeError
 		If inputted keyword arguments are not acceptable strings.
@@ -1395,12 +1501,39 @@ def T_from_Deq(Deq, clumps = 'CO47', calibration = 'Bea17', ref_frame = 'CDES90'
 	[2] Dennis et al. (2011) *Geochim. Cosmochim. Ac.*, **75**, 7117--7131.\n
 	[3] Passey and Henkes (2012) *Earth Planet. Sci. Lett.*, **351**, 223--236.\n
 	[4] Stolper and Eiler (2015) *Am. J. Sci.*, **315**, 363--411.\n
-	[5] Bonifacie et al. (2017) *Geochim. Cosmochim. Ac.*, **200**, 255--279.
+	[5] Bonifacie et al. (2017) *Geochim. Cosmochim. Ac.*, **200**, 255--279. \n
+	[6] Anderson et al. (2021) *Geophys. Res. Lett.*, **48**, e2020GL092069. \n
 	'''
 
 	#make sure clumps is CO47 and extract function from dictionary
 	if clumps == 'CO47':
-		func = caleqs[calibration][ref_frame]
+
+		#if calibration is a string, calculate Deq from the dictionaries
+		if isinstance(calibration, str):
+			
+			if calibration in ['PH12', 'SE15', 'Bea17', 'Aea21']:
+				#get Deq from dictionary
+				func = caleqs[calibration][ref_frame]
+
+			else:
+				#wrong string; raise error
+				raise ValueError(
+					"unexpected calibration %s. Must be 'PH12', 'SE15', 'Bea17',"
+					" Aea21', or lambda function."
+					% calibration
+					)
+
+		#if it's a lambda function, calculate Deq directly
+		elif isinstance(calibration, types.FunctionType):
+			func = calibration
+
+		#if it's neither, raise typeerror
+		else:
+			ct = type(calibration).__name__
+			raise TypeError(
+				'unexpected calibration of type %s. Must be string or '
+				'LambdaType.' % ct
+				)
 	
 	elif isinstance(clumps, str):
 		raise ValueError(
