@@ -14,8 +14,8 @@ __docformat__ = 'restructuredtext en'
 __all__ = ['calc_L_curve',
 		   'fit_Arrhenius',
 		   'fit_Hea14',
-		   'fit_HH20',
-		   'fit_HH20inv',
+		   'fit_HH21',
+		   'fit_HH21inv',
 		   'fit_PH12',
 		   'fit_SE15',
 		  ]
@@ -52,7 +52,7 @@ from .calc_funcs import(
 	_fPH12,
 	_fSE15,
 	_Gaussian,
-	_fHH20,
+	_fHH21,
 	)
 
 #import necessary isotopylog core functions
@@ -150,13 +150,13 @@ def calc_L_curve(
 	See Also
 	--------
 
-	isotopylog.fit_HH20inv
+	isotopylog.fit_HH21inv
 		Method for fitting heating experiment data using the L-curve approach
-		of Hemingway and Henkes (2020).
+		of Hemingway and Henkes (2021).
 
 	kDistribution.invert_experiment
 		Method for generating a `kDistribution` instance from experimental
-		data; can generate L curve if `model = "HH20"` and `fit_reg = True`.
+		data; can generate L curve if `model = "HH21"` and `fit_reg = True`.
 
 	Examples
 	--------
@@ -199,7 +199,7 @@ def calc_L_curve(
 
 	[1] Hansen (1994) *Numerical Algorithms*, **6**, 1-35.\n
 	[2] Forney and Rothman (2012) *J. Royal Soc. Inter.*, **9**, 2255--2267.\n
-	[3] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[3] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
 	'''
 	
 	#extract arrays
@@ -219,7 +219,7 @@ def calc_L_curve(
 	for i, w in enumerate(om_vec):
 
 		#call the inverse fit parent function
-		_, _, res_inv, rgh_inv = fit_HH20inv(
+		_, _, res_inv, rgh_inv = fit_HH21inv(
 			he, 
 			nu_max = nu_max,
 			nu_min = nu_min,
@@ -359,7 +359,7 @@ def fit_Arrhenius(
 
 	zero_int : boolean
 		Tells the function whether or not to force the intercept to zero.
-		This is used for calculating sig_E in the 'HH20' model and
+		This is used for calculating sig_E in the 'HH21' model and
 		ln([p0]/[peq]) for the 'SE15' model, both of which are expected to have
 		zero intercept in ln(k) vs. 1/T space.
 
@@ -513,9 +513,9 @@ def fit_Hea14(he, logy = True, p0 = [-10., -10., -10.]):
 	See Also
 	--------
 
-	isotopylog.fit_HH20
+	isotopylog.fit_HH21
 		Method for fitting heating experiment data using the distributed
-		activation energy model of Hemingway and Henkes (2020).
+		activation energy model of Hemingway and Henkes (2021).
 
 	isotopylog.fit_PH12
 		Method for fitting heating experiment data using the pseudo first-
@@ -586,7 +586,6 @@ def fit_Hea14(he, logy = True, p0 = [-10., -10., -10.]):
 		he.dex[0,0],
 		Ghat,
 		he.T,
-		# calibration = he.calibration,
 		he.caleq,
 		clumps = he.clumps,
 		G_std = None,
@@ -598,13 +597,13 @@ def fit_Hea14(he, logy = True, p0 = [-10., -10., -10.]):
 
 	return params, params_cov, rmse, npt
 
-#function to fit data using HH20 lognormal model
-def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
+#function to fit data using HH21 lognormal model
+def fit_HH21(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 	'''
 	Fits D evolution data using the distributed activation energy model of
-	Hemingway and Henkes (2020). This function solves for mu_nu and sig_nu,
+	Hemingway and Henkes (2021). This function solves for mu_nu and sig_nu,
 	the mean and standard deviation of a Gaussian distribution in lnk space.
-	See HH20 Eq. X for notation and details.
+	See HH21 Eq. 24 for notation and details.
 
 	Parameters
 	----------
@@ -666,9 +665,9 @@ def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 		equilibrium model of Henkes et al. (2014). 'Hea14' can be considered
 		an updated version of the present method.
 
-	isotopylog.fit_HH20inv
+	isotopylog.fit_HH21inv
 		Method for fitting heating experiment data using the L-curve approach
-		of Hemingway and Henkes (2020).
+		of Hemingway and Henkes (2021).
 
 	isotopylog.fit_PH12
 		Method for fitting heating experiment data using the pseudo first-
@@ -693,12 +692,12 @@ def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 		import isotopylog as ipl
 
 		#assume he is a HeatingExperiment instance
-		results = ipl.fit_HH20(he)
+		results = ipl.fit_HH21(he)
 
 	References
 	----------
 
-	[1] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[1] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **566**, 116962.
 	'''
 
 	#extract values to fit
@@ -712,7 +711,7 @@ def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 	nu = np.linspace(nu_min, nu_max, nnu)
 
 	#fit model to lambda function to allow inputting constants
-	lamfunc = lambda x, mu_nu, sig_nu: _fHH20(
+	lamfunc = lambda x, mu_nu, sig_nu: _fHH21(
 		x, 
 		mu_nu, 
 		sig_nu, 
@@ -740,7 +739,6 @@ def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 		he.dex[0,0],
 		Ghat,
 		he.T,
-		# calibration = he.calibration,
 		he.caleq,
 		clumps = he.clumps,
 		G_std = None,
@@ -752,8 +750,8 @@ def fit_HH20(he, nu_max = 10, nu_min = -50, nnu = 300, p0 = [-20, 5]):
 
 	return params, params_cov, rmse, npt, nu, rho_nu
 
-#function to fit data using the HH20 inverse model
-def fit_HH20inv(
+#function to fit data using the HH21 inverse model
+def fit_HH21inv(
 	he,
 	nu_max = 10,
 	nu_min = -50,
@@ -764,8 +762,8 @@ def fit_HH20inv(
 	):
 	'''
 	Fits D evolution data using the distributed activation energy model of
-	Hemingway and Henkes (2020). This function solves for rho_nu, the
-	regularized distribution of rates in lnk space. See HH20 Eq. X for
+	Hemingway and Henkes (2021). This function solves for rho_nu, the
+	regularized distribution of rates in lnk space. See HH21 Eq. X for
 	notation and details. This function can estimate best-fit omega using
 	Tikhonov regularization.
 	
@@ -823,9 +821,9 @@ def fit_HH20inv(
 	See Also
 	--------
 
-	isotopylog.fit_HH20
+	isotopylog.fit_HH21
 		Method for fitting heating experiment data using the lognormal model
-		of Hemingway and Henkes (2020).
+		of Hemingway and Henkes (2021).
 
 	kDistribution.invert_experiment
 		Method for generating a `kDistribution` instance from experimental
@@ -841,7 +839,7 @@ def fit_HH20inv(
 		import isotopylog as ipl
 
 		#assume he is a HeatingExperiment instance
-		results = ipl.fit_HH20inv(he, omega = 'auto')
+		results = ipl.fit_HH21inv(he, omega = 'auto')
 
 	Same implementation, but if best-fit `omega` is known a priori::
 
@@ -852,13 +850,13 @@ def fit_HH20inv(
 		omega = 3
 
 		#assume he is a HeatingExperiment instance
-		results = ipl.fit_HH20inv(he, omega = 3)
+		results = ipl.fit_HH21inv(he, omega = 3)
 
 	References
 	----------
 
 	[1] Forney and Rothman (2012) *J. Royal Soc. Inter.*, **9**, 2255--2267.\n
-	[2] Hemingway and Henkes (2020) *Earth Planet. Sci. Lett.*, **X**, XX--XX.
+	[2] Hemingway and Henkes (2021) *Earth Planet. Sci. Lett.*, **566**, 116962.
 	'''
 
 	#extract variables
@@ -930,7 +928,6 @@ def fit_HH20inv(
 		he.dex[0,0],
 		Ghat,
 		he.T,
-		# calibration = he.calibration,
 		he.caleq,
 		clumps = he.clumps,
 		G_std = None,
@@ -1015,9 +1012,9 @@ def fit_PH12(he, logy = True, p0 = [-10., 0.5], thresh = 1e-10):
 		equilibrium model of Henkes et al. (2014). 'Hea14' can be considered
 		an updated version of the present method.
 
-	isotopylog.fit_HH20
+	isotopylog.fit_HH21
 		Method for fitting heating experiment data using the distributed
-		activation energy model of Hemingway and Henkes (2020).
+		activation energy model of Hemingway and Henkes (2021).
 
 	isotopylog.fit_SE15
 		Method for fitting heatinge experiment data using the paird diffusion
@@ -1100,7 +1097,6 @@ def fit_PH12(he, logy = True, p0 = [-10., 0.5], thresh = 1e-10):
 		he.dex[0,0],
 		Ghat,
 		he.T,
-		# calibration = he.calibration,
 		he.caleq,
 		clumps = he.clumps,
 		G_std = None,
@@ -1190,9 +1186,9 @@ def fit_SE15(he, p0 = [-7., -9., 0.0992], mp = None, z = 6):
 		equilibrium model of Henkes et al. (2014). 'Hea14' can be considered
 		an updated version of the present method.
 
-	isotopylog.fit_HH20
+	isotopylog.fit_HH21
 		Method for fitting heating experiment data using the distributed
-		activation energy model of Hemingway and Henkes (2020).
+		activation energy model of Hemingway and Henkes (2021).
 
 	isotopylog.fit_PH12
 		Method for fitting heating experiment data using the pseudo first-
@@ -1254,7 +1250,7 @@ def fit_SE15(he, p0 = [-7., -9., 0.0992], mp = None, z = 6):
 			mpfit,
 			d0,
 			T,
-			calibration = he.calibration,
+			calibration = he.caleq,
 			iso_params = he.iso_params,
 			ref_frame = he.ref_frame,
 			z = z,
@@ -1276,7 +1272,7 @@ def fit_SE15(he, p0 = [-7., -9., 0.0992], mp = None, z = 6):
 			mp,
 			d0,
 			T,
-			calibration = he.calibration,
+			calibration = he.caleq,
 			iso_params = he.iso_params,
 			ref_frame = he.ref_frame,
 			z = z,
